@@ -9,7 +9,7 @@
 #' @return [[numeric]]
 qc_positive_control <- function(counts) {
   measured <- log2(counts[["Count"]])
-  known <- log2(as.numeric(gsub("^[^(]*\\((.*)\\)$", "\\1", counts[["Name"]]))) # plexset value: "32"
+  known <- log2(as.numeric(sub("^[^(]*\\((.*)\\)$", "\\1", counts[["Name"]]))) # plexset value: "32"
   correlation <- stats::cor.test(known, measured)$estimate
   unname(round(correlation, 5))
-}
\ No newline at end of file
+}
