@@ -1,3 +1,3 @@
-test_that('deploy to temp dir', {
+test_that("deploy to temp dir", {
   expect_true(deploy(directory = tempdir()))
-})
\ No newline at end of file
+})
